@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GHex; see the file COPYING.
-   If not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   If not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Authors:
    Jaka Mocnik <jaka@gnu.org>
